@@ -14,8 +14,11 @@ import probscale
 from probscale.probscale import _minimal_norm
 
 
-PYTHON27 = sys.version_info.major == 2
-TOLERANCE = 22
+PY27 = sys.version_info.major == 2
+if PY27:
+    TOLERANCE = 25
+else:
+    TOLERANCE = 22
 
 
 @pytest.fixture
@@ -55,9 +58,9 @@ def test_minimal_norm__approx_inv_erf(mn, mn_input):
 
 def test_minimal_norm_ppf(mn, mn_input):
     known_ppf = numpy.array([
-        -0.43715354,  0.6495236 , -1.49851307,  0.93847570,
+        -0.43715354,  0.64952360, -1.49851307,  0.93847570,
         -0.36648929, -1.34693863,  0.68713129, -0.40701088,
-         0.71275076,  0.40701088, -0.70952297,  1.34075503,
+        +0.71275076,  0.40701088, -0.70952297,  1.34075503,
     ])
     diff = mn.ppf(mn_input) - known_ppf
     assert numpy.all(numpy.abs(diff) < 0.001)
@@ -77,7 +80,7 @@ def test_minimal_norm_cdf(mn, mn_input):
     baseline_dir='baseline_images/test_probscale',
     tolerance=TOLERANCE
 )
-@pytest.mark.skipif(PYTHON27, reason="legacy python")
+@pytest.mark.skipif(PY27, reason="legacy python")
 def test_the_scale_default():
     fig, ax = plt.subplots(figsize=(4, 8))
     ax.set_yscale('prob')
@@ -99,7 +102,7 @@ def test_the_scale_not_as_pct():
 
 @pytest.mark.mpl_image_compare(
     baseline_dir='baseline_images/test_probscale',
-    tolerance=13
+    tolerance=TOLERANCE
 )
 @pytest.mark.skipif(stats is None, reason="scipy not installed")
 def test_the_scale_beta():
