@@ -1,18 +1,18 @@
-﻿import copy
+import copy
 
 import numpy
 from matplotlib import pyplot
 
 from .probscale import _minimal_norm
 from . import validate
+from . import algo
 
 
 def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
              problabel=None, datascale='linear', datalabel=None,
-             bestfit=False, estimate_ci=False,
-             return_best_fit_results=False,
-             scatter_kws=None, line_kws=None, pp_kws=None,
-             **fgkwargs):
+             bestfit=False, return_best_fit_results=False,
+             estimate_ci=False, ci_kws=None, pp_kws=None,
+             scatter_kws=None, line_kws=None, **fgkwargs):
     """
     Probability, percentile, and quantile plots.
 
@@ -20,9 +20,11 @@ def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
     ----------
     data : array-like
         1-dimensional data to be plotted
+
     ax : matplotlib axes, optional
         The Axes on which to plot. If one is not provided, a new Axes
         will be created.
+
     plottype : string (default = 'prob')
         Type of plot to be created. Options are:
 
@@ -30,29 +32,45 @@ def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
            - 'pp': percentile plot
            - 'qq': quantile plot
 
+
     dist : scipy distribution, optional
         A distribtion to compute the scale's tick positions. If not
         specified, a standard normal distribution will be used.
+
     probax : string, optional (default = 'x')
         The axis ('x' or 'y') that will serve as the probability (or
         quantile) axis.
+
     problabel, datalabel : string, optional
         Axis labels for the probability/quantile and data axes
         respectively.
+
     datascale : string, optional (default = 'log')
         Scale for the other axis that is not
+
     bestfit : bool, optional (default is False)
         Specifies whether a best-fit line should be added to the plot.
+
     return_best_fit_results : bool (default is False)
         If True a dictionary of results of is returned along with the
         figure.
-    scatter_kws, line_kws : dictionary, optional
-        Dictionary of keyword arguments passed directly to ``ax.plot``
-        when drawing the scatter points and best-fit line, respectively.
-    pp_kws : dictionary, optional
+
+    estimate_ci : bool, optional (False)
+        Estimate and draw a confidence band around the best-fit line
+        using a percentile bootstrap.
+
+    ci_kws : dict, optional
+        Dictionary of keyword arguments passed directly to
+        ``viz.fit_line`` when computing the best-fit line.
+
+    pp_kws : dict, optional
         Dictionary of keyword arguments passed directly to
         ``viz.plot_pos`` when computing the plotting positions.
 
+    scatter_kws, line_kws : dict, optional
+        Dictionary of keyword arguments passed directly to ``ax.plot``
+        when drawing the scatter points and best-fit line, respectively.
+
     Other Parameters
     ----------------
     color : string, optional
@@ -63,8 +81,9 @@ def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
         specified within ``scatter_kws`` and ``line_kws``.
 
         .. note::
-           Users should not specify the parameter. It is inteded to only
-           be used by seaborn when operating within a FacetGrid.
+           Users should not specify this parameter. It is inteded to
+           only be used by seaborn when operating within a
+           ``FacetGrid``.
 
     label : string, optional
         A directly-specified legend label for the data series. This
@@ -73,15 +92,17 @@ def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
         data series label should be specified within ``scatter_kws``.
 
         .. note::
-           Users should not specify the parameter. It is inteded to only
-           be used by seaborn when operating within a FacetGrid.
+           Users should not specify this parameter. It is inteded to
+           only be used by seaborn when operating within a
+           ``FacetGrid``.
 
 
     Returns
     -------
     fig : matplotlib.Figure
         The figure on which the plot was drawn.
-    result : dictionary of linear fit results, optional
+
+    result : dict of linear fit results, optional
         Keys are:
 
            - q : array of quantiles
@@ -92,6 +113,7 @@ def probplot(data, ax=None, plottype='prob', dist=None, probax='x',
     See also
     --------
     viz.plot_pos
+    viz.fit_line
     numpy.polyfit
     scipy.stats.probplot
     scipy.stats.mstats.plotting_positions
@@ -286,7 +308,9 @@ def plot_pos(data, postype=None, alpha=None, beta=None):
     ----------
     data : array-like
         The values whose plotting positions need to be computed.
+
     postype : string, optional (default: "cunnane")
+
     alpha, beta : float, optional
         Custom plotting position parameters is the options available
         through the `postype` parameter are insufficient.
@@ -295,6 +319,7 @@ def plot_pos(data, postype=None, alpha=None, beta=None):
     -------
     plot_pos : numpy.array
         The computed plotting positions, sorted.
+
     data_sorted : numpy.array
         The original data values, sorted.
 
@@ -361,33 +386,19 @@ def _set_prob_limits(ax, probax, N):
     fig, ax = validate.axes_object(ax)
     which = validate.axis_name(probax, 'probability axis')
 
-    minval = 10 ** (-1 *numpy.ceil(numpy.log10(N) - 2))
+    if N <= 5:
+        minval = 10
+    elif N <= 10:
+        minval = 5
+    else:
+        minval = 10 ** (-1 * numpy.ceil(numpy.log10(N) - 2))
+
     if which in ['x', 'both']:
         ax.set_xlim(left=minval, right=100-minval)
     elif which in ['y', 'both']:
         ax.set_ylim(bottom=minval, top=100-minval)
 
 
-def _make_boot_index(elements, niter):
-    """ Generate an array of bootstrap sample sets
-
-    Parameters
-    ----------
-    elements : int
-        The number of rows in the original dataset.
-    niter : int
-        Number of iteration for the bootstrapping.
-
-    Returns
-    -------
-    index : numpy array
-        A collection of random *indices* that can be used to randomly
-        sample a dataset ``niter`` times.
-
-    """
-    return numpy.random.randint(low=0, high=elements, size=(niter, elements))
-
-
 def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
              estimate_ci=False, niter=10000, alpha=0.05):
     """
@@ -397,22 +408,36 @@ def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
     ----------
     x, y : array-like
         Independent and dependent data, respectively.
+
     xhat : array-like, optional
         The values at which ``yhat`` should should be estimated. If
         not provided, falls back to the sorted values of ``x``.
+
     fitprobs, fitlogs : str, optional.
         Defines how data should be transformed. Valid values are
         'x', 'y', or 'both'. If using ``fitprobs``, variables should
         be expressed as a percentage, i.e.,
-        Probablility transform = lambda x: ``dist``.ppf(x / 100.).
-        Log transform = lambda x: numpy.log(x).
+        for a probablility transform, data will be transformed with
+        ``lambda x: dist.ppf(x / 100.)``.
+        For a log transform, ``lambda x: numpy.log(x)``.
         Take care to not pass the same value to both ``fitlogs`` and
         ``figprobs`` as both transforms will be applied.
+
     dist : distribution, optional
         A fully-spec'd scipy.stats distribution-like object
         such that ``dist.ppf`` and ``dist.cdf`` can be called. If not
         provided, defaults to a minimal implementation of
-        scipt.stats.norm.
+        ``scipt.stats.norm``.
+
+    estimate_ci : bool, optional (False)
+        Estimate and draw a confidence band around the best-fit line
+        using a percentile bootstrap.
+
+    niter : int, optional (default = 10000)
+        Number of bootstrap iterations if ``estimate_ci`` is provided.
+
+    alpha : float, optional (default = 0.05)
+        The confidence level of the bootstrap estimate.
 
     Returns
     -------
@@ -427,6 +452,7 @@ def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
           - yhat_hi (upper confidence interval of the estimated y-vals)
 
     """
+
     fitprobs = validate.fit_argument(fitprobs, "fitprobs")
     fitlogs = validate.fit_argument(fitlogs, "fitlogs")
 
@@ -440,12 +466,12 @@ def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
 
     # maybe compute ppf of x
     if fitprobs in ['x', 'both']:
-        x = dist.ppf(x/100.)
+        x = dist.ppf(x / 100.)
         xhat = dist.ppf(numpy.array(xhat)/100.)
 
     # maybe compute ppf of y
     if fitprobs in ['y', 'both']:
-        y  = dist.ppf(y/100.)
+        y  = dist.ppf(y / 100.)
 
     # maybe compute log of x
     if fitlogs in ['x', 'both']:
@@ -455,11 +481,11 @@ def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
     if fitlogs in ['y', 'both']:
         y = numpy.log(y)
 
-    yhat, results =  _fit_simple(x, y, xhat, fitlogs=fitlogs)
+    yhat, results =  algo._fit_simple(x, y, xhat, fitlogs=fitlogs)
 
     if estimate_ci:
-        yhat_lo, yhat_hi = _fit_ci(x, y, xhat, fitlogs=fitlogs,
-                                   niter=niter, alpha=alpha)
+        yhat_lo, yhat_hi = algo._bs_fit(x, y, xhat, fitlogs=fitlogs,
+                                        niter=niter, alpha=alpha)
     else:
         yhat_lo, yhat_hi = None, None
 
@@ -478,123 +504,3 @@ def fit_line(x, y, xhat=None, fitprobs=None, fitlogs=None, dist=None,
     results['yhat_hi'] = yhat_hi
 
     return xhat, yhat, results
-
-
-def _fit_simple(x, y, xhat, fitlogs=None):
-    """
-    Simple linear fit of x and y data using ``numpy.polyfit``.
-
-    Parameters
-    ----------
-    x, y : array-like
-    fitlogs : str, optional.
-        Defines which data should be log-transformed. Valid values are
-        'x', 'y', or 'both'.
-
-    Returns
-    -------
-    xhat, yhat : array-like
-        Estimates of x and y based on the linear fit
-    results : dict
-        Dictionary of the fit coefficients
-
-    See also
-    --------
-    numpy.polyfit
-
-    """
-
-    # do the best-fit
-    coeffs = numpy.polyfit(x, y, 1)
-
-    results = {
-        'slope': coeffs[0],
-        'intercept': coeffs[1]
-    }
-
-    # estimate y values
-    yhat = _estimate_from_fit(xhat, coeffs[0], coeffs[1],
-                              xlog=fitlogs in ['x', 'both'],
-                              ylog=fitlogs in ['y', 'both'])
-
-    return yhat, results
-
-
-def _fit_ci(x, y, xhat, fitlogs=None, niter=10000, alpha=0.05):
-    """
-    Percentile method bootstrapping of linear fit of x and y data using
-    ``numpy.polyfit``.
-
-    Parameters
-    ----------
-    x, y : array-like
-    fitlogs : str, optional.
-        Defines which data should be log-transformed. Valid values are
-        'x', 'y', or 'both'.
-    niter : int, optional (default is 10000)
-        Number of bootstrap iterations to use
-    alpha : float, optional
-        Confidence level of the estimate.
-
-    Returns
-    -------
-    xhat, yhat : array-like
-        Estimates of x and y based on the linear fit
-    results : dict
-        Dictionary of the fit coefficients
-
-    See also
-    --------
-    numpy.polyfit
-
-    """
-
-    index = _make_boot_index(len(x), niter)
-    yhat_array = numpy.array([
-        _fit_simple(x[ii], y[ii], xhat, fitlogs=fitlogs)[0]
-        for ii in index
-    ])
-
-    percentiles = 100 * numpy.array([alpha*0.5, 1 - alpha*0.5])
-    yhat_lo, yhat_hi = numpy.percentile(yhat_array, percentiles, axis=0)
-    return yhat_lo, yhat_hi
-
-
-def _estimate_from_fit(xhat, slope, intercept, xlog=False, ylog=False):
-    """ Estimate the dependent variables of a linear fit given x-data
-    and linear parameters.
-
-    Parameters
-    ----------
-    xhat : numpy array or pandas Series/DataFrame
-        The input independent variable of the fit
-    slope : float
-        Slope of the best-fit line
-    intercept : float
-        y-intercept of the best-fit line
-    xlog, ylog : bool (default = False)
-        Toggles whether or not the logs of the x- or y- data should be
-        used to perform the regression.
-
-    Returns
-    -------
-    yhat : numpy array
-        Estimate of the dependent variable.
-
-    """
-
-    xhat = numpy.asarray(xhat)
-    if ylog:
-        if xlog:
-            yhat = numpy.exp(intercept) * xhat  ** slope
-        else:
-            yhat = numpy.exp(intercept) * numpy.exp(slope) ** xhat
-
-    else:
-        if xlog:
-            yhat = slope * numpy.log(xhat) + intercept
-
-        else:
-            yhat = slope * xhat + intercept
-
-    return yhat
